#!/bin/awk -f

function realtime (t) {
  sub(/,/, ".", t);
  split(t, artime, /:/);

  rt = 0;
  for (i in artime) rt = rt * 60 + artime[i];

  return rt;
}

function printtime (rt) {
  f = sprintf("%.2f", rt);
  sub(/^.*\./, "", f);
  t = sprintf("%02d.%s", int(rt % 60), f);
  for (i=1; i<3; i++) {
    rt = int (rt / 60);
    temp = rt % 60;
    t = sprintf("%02d:%s", temp, t);
  }
  return t;
}

BEGIN {
  if ((ARGC < 3) || (ARGC > 4)) {
    printf "Usage: SubRipSplit.awk <time> <input> [output]\n" \
      >> "/dev/stderr";
    printf " time: median time ([+-]HH:MM:SS.mm)\n" >> "/dev/stderr";
    exit(-1);
  }
  
  output1 = (ARGC == 4) ? ARGV[3] ".1" : ARGV[2] ".1";
  output2 = (ARGC == 4) ? ARGV[3] ".2" : ARGV[2] ".2";
  printf "" > output1;
  printf "" > output2;
  
  time = realtime(ARGV[1]);
  
  ARGV[3] = ARGV[1] = "";
  header = 1;
  file = "1";
}

# For dos and mac
{
  sub(/\r/, "", $0);
  sub(/\f/, "", $0);
}

$1 ~ /[0-9][0-9]:[0-9][0-9]:[0-9][0-9].[0-9][0-9],[0-9][0-9]:[0-9][0-9]:[0-9][0-9].[0-9][0-9]/ {
  
  split($1, arline, /,/);
  
  beg = realtime(arline[1]);
  end = realtime(arline[2]);
  
  file = (time > end) ? "1" : ((time > beg) ? "12" : "2");
  
  header = 0;

  if (file == "1") {
    $0 = printtime(beg) "," printtime(end);
  } else if (file == "2") {
    $0 = printtime(beg - time) "," printtime(end - time);
  } else {
    $0 = printtime(beg) "," printtime(time);
    file = "1";
    printf "%s,%s\n", printtime(0), printtime(end - time) >> output2;
  }
}

{
  if ((file ~ /1/) || (header == 1)) {
    printf "%s\n", $0 >> output1;
  }
  if ((file ~ /2/) || (header == 1)) {
    printf "%s\n", $0 >> output2;
  }
}
