#!/bin/awk -f

function realtime (t) {
  
  sub(/:[0-9][0-9]?$/, ":&", t);
  s = (t ~ /:[0-9]$/) ? ".0" : ".";
  sub(/::/, s, t);

  split(t, artime, /:/);

  rt = 0;
  for (i in artime) rt = rt * 60 + artime[i];

  return rt;
}

function printtime (rt) {
  f = sprintf("%.3f", rt);
  sub(/^.*\./, "", f);
  t = sprintf("%02d,%s", int(rt % 60), f);
  for (i=1; i<3; i++) {
    rt = int (rt / 60);
    temp = rt % 60;
    t = sprintf("%02d:%s", temp, t);
  }
  return t;
}

BEGIN {
  if ((ARGC < 3) || (ARGC > 4)) {
    printf "Usage: SubViewer2SubRipper.awk <dpst> <input> [output]\n" \
      >> "/dev/stderr";
    printf " dpst: delay per sub-title (in second)\n" >> "/dev/stderr";
    exit(-1);
  }

  output = (ARGC == 4) ? ARGV[3] : "";
  if (output != "") printf "" > output;

  dpst = ARGV[1];
  sub(/,/, ".", dpst);

  ARGV[3] = ARGV[1] = "";

  header = 1;
  ind = 0;
}

# For dos and mac
{
  sub(/\r/, "", $0);
  sub(/\f/, "", $0);
}

($1 == "{T") && ($2 ~ /[0-9][0-9]:[0-9][0-9]:[0-9][0-9]:[0-9][0-9]/) {
  
  beg = realtime($2);
  end = beg + dpst; 

  header = 0;

  ind++;
  if (output == "") {
    printf "%d\n", ind;
  } else {
    printf "%d\n", ind >> output;
  }

  $0 = printtime(beg) " --> " printtime(end);
}

!header {
  sub(/\}$/, "");
  if (output == "") {
    printf "%s\n", $0;
  } else {
    printf "%s\n", $0 >> output;
  }
}
